@@ -1,3 +1,5 @@
+# pylint: disable=no-member
+
 from django.views import generic
 from django.views.generic.edit import CreateView, UpdateView
 from django.views.generic import TemplateView, ListView
@@ -143,6 +145,13 @@ class BatteryList(PagedFilteredTableView):
 class BatteryDetail(generic.DetailView):
     model = Battery
 
+    def get_context_data(self, **kwargs):
+        context = super().get_context_data(**kwargs)
+
+        if self.get_object().history.all():
+            context['history'] = self.get_object().history.all()
+        return context
+
 
 class BatteryCreate(LoginRequiredMixin, CreateView):
     model = Battery
@@ -243,9 +252,23 @@ class CameraModelDetail(generic.DetailView):
 
     def get_context_data(self, **kwargs):
         context = super().get_context_data(**kwargs)
-        context['related'] = self.get_object().tags.similar_objects()
-        context['mine'] = self.get_object().camera_set.filter(
-            owner=self.request.user)
+
+        # Find similar objects of the same type
+        similarobjects = self.get_object().tags.similar_objects()
+        items = []
+        for item in similarobjects:
+            if type(item) == type(self.get_object()):  # pylint: disable=unidiomatic-typecheck
+                detailitem = get_object_or_404(type(item), pk=item.pk)
+                items.append(detailitem)
+        context['related'] = items
+
+        if self.request.user.is_authenticated:
+            context['mine'] = self.get_object().camera_set.filter(
+                owner=self.request.user)
+
+        if self.get_object().history.all():
+            context['history'] = self.get_object().history.all()
+
         return context
 
 
@@ -273,7 +296,18 @@ class DeveloperDetail(generic.DetailView):
 
     def get_context_data(self, **kwargs):
         context = super().get_context_data(**kwargs)
-        context['related'] = self.get_object().tags.similar_objects()
+        # Find similar objects of the same type
+        similarobjects = self.get_object().tags.similar_objects()
+        items = []
+        for item in similarobjects:
+            if type(item) == type(self.get_object()):  # pylint: disable=unidiomatic-typecheck
+                detailitem = get_object_or_404(type(item), pk=item.pk)
+                items.append(detailitem)
+        context['related'] = items
+
+        if self.get_object().history.all():
+            context['history'] = self.get_object().history.all()
+
         return context
 
 
@@ -332,7 +366,18 @@ class FilmStockDetail(generic.DetailView):
 
     def get_context_data(self, **kwargs):
         context = super().get_context_data(**kwargs)
-        context['related'] = self.get_object().tags.similar_objects()
+        # Find similar objects of the same type
+        similarobjects = self.get_object().tags.similar_objects()
+        items = []
+        for item in similarobjects:
+            if type(item) == type(self.get_object()):  # pylint: disable=unidiomatic-typecheck
+                detailitem = get_object_or_404(type(item), pk=item.pk)
+                items.append(detailitem)
+        context['related'] = items
+
+        if self.get_object().history.all():
+            context['history'] = self.get_object().history.all()
+
         return context
 
 
@@ -404,6 +449,12 @@ class FlashProtocolList(SingleTableListView):
     model = FlashProtocol
     table_class = FlashProtocolTable
 
+    def get_context_data(self, **kwargs):
+        context = super().get_context_data(**kwargs)
+        if self.get_object().history.all():
+            context['history'] = self.get_object().history.all()
+        return context
+
 
 class FlashProtocolDetail(generic.DetailView):
     model = FlashProtocol
@@ -429,6 +480,12 @@ class FormatList(SingleTableListView):
 class FormatDetail(generic.DetailView):
     model = Format
 
+    def get_context_data(self, **kwargs):
+        context = super().get_context_data(**kwargs)
+        if self.get_object().history.all():
+            context['history'] = self.get_object().history.all()
+        return context
+
 
 class FormatCreate(LoginRequiredMixin, CreateView):
     model = Format
@@ -498,9 +555,23 @@ class LensModelDetail(generic.DetailView):
 
     def get_context_data(self, **kwargs):
         context = super().get_context_data(**kwargs)
-        context['related'] = self.get_object().tags.similar_objects()
-        context['mine'] = self.get_object().lens_set.filter(
-            owner=self.request.user)
+
+        # Find similar objects of the same type
+        similarobjects = self.get_object().tags.similar_objects()
+        items = []
+        for item in similarobjects:
+            if type(item) == type(self.get_object()):  # pylint: disable=unidiomatic-typecheck
+                detailitem = get_object_or_404(type(item), pk=item.pk)
+                items.append(detailitem)
+        context['related'] = items
+
+        if self.request.user.is_authenticated:
+            context['mine'] = self.get_object().lens_set.filter(
+                owner=self.request.user)
+
+        if self.get_object().history.all():
+            context['history'] = self.get_object().history.all()
+
         return context
 
 
@@ -526,7 +597,19 @@ class ManufacturerDetail(generic.DetailView):
 
     def get_context_data(self, **kwargs):
         context = super().get_context_data(**kwargs)
-        context['related'] = self.get_object().tags.similar_objects()
+
+        # Find similar objects of the same type
+        similarobjects = self.get_object().tags.similar_objects()
+        items = []
+        for item in similarobjects:
+            if type(item) == type(self.get_object()):  # pylint: disable=unidiomatic-typecheck
+                detailitem = get_object_or_404(type(item), pk=item.pk)
+                items.append(detailitem)
+        context['related'] = items
+
+        if self.get_object().history.all():
+            context['history'] = self.get_object().history.all()
+
         return context
 
 
@@ -554,7 +637,19 @@ class MountDetail(generic.DetailView):
 
     def get_context_data(self, **kwargs):
         context = super().get_context_data(**kwargs)
-        context['related'] = self.get_object().tags.similar_objects()
+
+        # Find similar objects of the same type
+        similarobjects = self.get_object().tags.similar_objects()
+        items = []
+        for item in similarobjects:
+            if type(item) == type(self.get_object()):  # pylint: disable=unidiomatic-typecheck
+                detailitem = get_object_or_404(type(item), pk=item.pk)
+                items.append(detailitem)
+        context['related'] = items
+
+        if self.get_object().history.all():
+            context['history'] = self.get_object().history.all()
+
         return context
 
 
@@ -605,6 +700,12 @@ class NegativeSizeList(SingleTableListView):
     model = NegativeSize
     table_class = NegativeSizeTable
 
+    def get_context_data(self, **kwargs):
+        context = super().get_context_data(**kwargs)
+        if self.get_object().history.all():
+            context['history'] = self.get_object().history.all()
+        return context
+
 
 class NegativeSizeDetail(generic.DetailView):
     model = NegativeSize
@@ -665,7 +766,19 @@ class PaperStockDetail(generic.DetailView):
 
     def get_context_data(self, **kwargs):
         context = super().get_context_data(**kwargs)
-        context['related'] = self.get_object().tags.similar_objects()
+
+        # Find similar objects of the same type
+        similarobjects = self.get_object().tags.similar_objects()
+        items = []
+        for item in similarobjects:
+            if type(item) == type(self.get_object()):  # pylint: disable=unidiomatic-typecheck
+                detailitem = get_object_or_404(type(item), pk=item.pk)
+                items.append(detailitem)
+        context['related'] = items
+
+        if self.get_object().history.all():
+            context['history'] = self.get_object().history.all()
+
         return context
 
 
@@ -941,7 +1054,19 @@ class TonerDetail(generic.DetailView):
 
     def get_context_data(self, **kwargs):
         context = super().get_context_data(**kwargs)
-        context['related'] = self.get_object().tags.similar_objects()
+
+        # Find similar objects of the same type
+        similarobjects = self.get_object().tags.similar_objects()
+        items = []
+        for item in similarobjects:
+            if type(item) == type(self.get_object()):  # pylint: disable=unidiomatic-typecheck
+                detailitem = get_object_or_404(type(item), pk=item.pk)
+                items.append(detailitem)
+        context['related'] = items
+
+        if self.get_object().history.all():
+            context['history'] = self.get_object().history.all()
+
         return context
 
 
